# libpythonpro

[ REPOSITÓRIO DE EXERCÍCIO ]

Módulo para exemplificar construção de projetos Python no curso PyTools. 
Neste curso é ensinado como contribuir com projetos de código aberto.

#### [Link da plataforma DevPro](Loginhttps://www.dev.pro.br) 

![distintivo de status GA CI](https://github.com/R-Lemos-prog/libpythonpro/actions/workflows/python-app.yml/badge.svg)

Suportada a versão 3 de Python

Para instalar: 
````commandline
py -3 -m venv .venv    
.venv/Scripts/activate
pip install -r requirements-dev.txt
   
````

Para conferir qualidade do código:
````commandline
flake8
````

Típicos a serem abordados:  
    1. Git  
    2. Virtualenv  
    3. Pip



